# Generated by h2py from /usr/include/netinet/in.h
_NETINET_IN_H = 1

# Included from features.h
_FEATURES_H = 1
def __GLIBC_USE(F): return __GLIBC_USE_ ## F

_DEFAULT_SOURCE = 1
_ISOC23_SOURCE = 1
_ISOC95_SOURCE = 1
_ISOC99_SOURCE = 1
_ISOC11_SOURCE = 1
_ISOC23_SOURCE = 1
_ISOC2Y_SOURCE = 1
_POSIX_SOURCE = 1
_POSIX_C_SOURCE = 202405L
_XOPEN_SOURCE = 800
_XOPEN_SOURCE_EXTENDED = 1
_LARGEFILE64_SOURCE = 1
_DEFAULT_SOURCE = 1
_ATFILE_SOURCE = 1
_DYNAMIC_STACK_SIZE_SOURCE = 1
_DEFAULT_SOURCE = 1
__GLIBC_USE_ISOC2Y = 1
__GLIBC_USE_ISOC2Y = 0
__GLIBC_USE_ISOC23 = 1
__GLIBC_USE_ISOC23 = 0
__USE_ISOC11 = 1
__USE_ISOC99 = 1
__USE_ISOC95 = 1
__USE_ISOC11 = 1
__USE_ISOCXX11 = 1
__USE_ISOC99 = 1
__USE_POSIX_IMPLICITLY = 1
_POSIX_SOURCE = 1
_POSIX_C_SOURCE = 202405L
_POSIX_SOURCE = 1
_POSIX_C_SOURCE = 2
_POSIX_C_SOURCE = 199506L
_POSIX_C_SOURCE = 200112L
_POSIX_C_SOURCE = 200809L
_POSIX_C_SOURCE = 202405L
__USE_POSIX_IMPLICITLY = 1
_POSIX_SOURCE = 1
_POSIX_C_SOURCE = 199506L
__USE_POSIX = 1
__USE_POSIX2 = 1
__USE_POSIX199309 = 1
__USE_POSIX199506 = 1
__USE_XOPEN2K = 1
__USE_ISOC95 = 1
__USE_ISOC99 = 1
__USE_XOPEN2K8 = 1
_ATFILE_SOURCE = 1
__USE_XOPEN2K24 = 1
__USE_XOPEN = 1
__USE_XOPEN_EXTENDED = 1
__USE_UNIX98 = 1
_LARGEFILE_SOURCE = 1
__USE_XOPEN2K8 = 1
__USE_XOPEN2K8XSI = 1
__USE_XOPEN2K24 = 1
__USE_XOPEN2K24XSI = 1
__USE_XOPEN2K = 1
__USE_XOPEN2KXSI = 1
__USE_ISOC95 = 1
__USE_ISOC99 = 1
__USE_XOPEN_EXTENDED = 1
__USE_LARGEFILE = 1
__USE_LARGEFILE64 = 1
__USE_FILE_OFFSET64 = 1

# Included from features-time64.h

# Included from bits/wordsize.h
__WORDSIZE = 64
__WORDSIZE = 32
__WORDSIZE32_SIZE_ULONG = 0
__WORDSIZE32_PTRDIFF_LONG = 0
__WORDSIZE_TIME64_COMPAT32 = 1
__SYSCALL_WORDSIZE = 64

# Included from bits/timesize.h
__TIMESIZE = 64
__TIMESIZE = __WORDSIZE
__USE_TIME_BITS64 = 1
__USE_TIME_BITS64 = 1
__USE_TIME64_REDIRECTS = 1
__USE_MISC = 1
__USE_ATFILE = 1
__USE_DYNAMIC_STACK_SIZE = 1
__USE_GNU = 1
__USE_FORTIFY_LEVEL = 3
__USE_FORTIFY_LEVEL = 2
__USE_FORTIFY_LEVEL = 1
__USE_FORTIFY_LEVEL = 0
__GLIBC_USE_DEPRECATED_GETS = 0
__GLIBC_USE_DEPRECATED_GETS = 1
__GLIBC_USE_DEPRECATED_SCANF = 1
__GLIBC_USE_DEPRECATED_SCANF = 0
__GLIBC_USE_C23_STRTOL = 1
__GLIBC_USE_C23_STRTOL = 0

# Included from stdc-predef.h
_STDC_PREDEF_H = 1
__STDC_IEC_559__ = 1
__STDC_IEC_60559_BFP__ = 201404L
__STDC_IEC_559__ = 1
__STDC_IEC_60559_BFP__ = 201404L
__STDC_IEC_559_COMPLEX__ = 1
__STDC_IEC_60559_COMPLEX__ = 201404L
__STDC_IEC_559_COMPLEX__ = 1
__STDC_IEC_60559_COMPLEX__ = 201404L
__STDC_ISO_10646__ = 201706L
__GNU_LIBRARY__ = 6
__GLIBC__ = 2
__GLIBC_MINOR__ = 43

# Included from sys/cdefs.h
_SYS_CDEFS_H = 1
def __glibc_has_attribute(attr): return __has_attribute (attr)

def __glibc_has_attribute(attr): return 0

def __glibc_has_builtin(name): return __has_builtin (name)

def __glibc_has_builtin(name): return 0

def __glibc_has_extension(ext): return __has_extension (ext)

def __glibc_has_extension(ext): return 0

def __NTH(fct): return fct

def __NTHNL(fct): return fct

def __NTH(fct): return fct

def __P(args): return args

def __PMT(args): return args

def __STRING(x): return #x

def __bos(ptr): return __builtin_object_size (ptr, __USE_FORTIFY_LEVEL > 1)

def __bos0(ptr): return __builtin_object_size (ptr, 0)

def __glibc_objsize0(__o): return __builtin_dynamic_object_size (__o, 0)

def __glibc_objsize(__o): return __builtin_dynamic_object_size (__o, 1)

def __glibc_objsize0(__o): return __bos0 (__o)

def __glibc_objsize(__o): return __bos (__o)

def __glibc_unsigned_or_positive(__l): return \

__fortify_use_clang = 1
def __fortify_clang_pass_object_size_n(n): return \

__fortify_clang_pass_object_size0 = \
  __fortify_clang_pass_object_size_n (0)
__fortify_clang_pass_object_size = \
  __fortify_clang_pass_object_size_n (__USE_FORTIFY_LEVEL > 1)
def __fortify_clang_pass_dynamic_object_size_n(n): return \

__fortify_clang_pass_dynamic_object_size0 = \
  __fortify_clang_pass_dynamic_object_size_n (0)
__fortify_clang_pass_dynamic_object_size = \
  __fortify_clang_pass_dynamic_object_size_n (1)
def __fortify_clang_unavailable(__msg): return \

__fortify_use_clang = 0
def __warnattr(msg): return __attribute__((__warning__ (msg)))

__flexarr = []
__glibc_c99_flexarr_available = 1
__flexarr = []
__glibc_c99_flexarr_available = 1
__flexarr = [0]
__glibc_c99_flexarr_available = 1
__flexarr = [1]
__glibc_c99_flexarr_available = 0
def __ASMNAME(cname): return __ASMNAME2 (__USER_LABEL_PREFIX__, cname)

def __attribute__(xyz): return  

def __attribute_alloc_size__(params): return \

def __attribute_alloc_size__(params): return  

def __attribute_alloc_align__(param): return \

def __attribute_alloc_align__(param): return  

def __attribute_deprecated_msg__(msg): return \

def __attribute_deprecated_msg__(msg): return __attribute_deprecated__

def __attribute_format_arg__(x): return __attribute__ ((__format_arg__ (x)))

def __attribute_format_arg__(x): return  

def __nonnull(params): return __attribute_nonnull__ (params)

def __glibc_unlikely(cond): return __builtin_expect ((cond), 0)

def __glibc_likely(cond): return __builtin_expect ((cond), 1)

def __glibc_unlikely(cond): return (cond)

def __glibc_likely(cond): return (cond)

def __attribute_copy__(arg): return __attribute__ ((__copy__ (arg)))


# Included from bits/long-double.h
__LDOUBLE_REDIRECTS_TO_FLOAT128_ABI = 0
def __LDBL_REDIR_DECL(name): return \

def __LDBL_REDIR2_DECL(name): return \

__LDBL_COMPAT = 1
def __LDBL_REDIR2_DECL(name): return \

def __LDBL_REDIR_DECL(name): return \

def __glibc_macro_warning(message): return \

__HAVE_GENERIC_SELECTION = 1
__HAVE_GENERIC_SELECTION = 0
def __attr_access_none(argno): return __attribute__ ((__access__ (__none__, argno)))

__USE_LARGEFILE = 1
__USE_LARGEFILE64 = 1
__USE_EXTERN_INLINES = 1

# Included from gnu/stubs.h

# Included from gnu/stubs-32.h

# Included from gnu/stubs-64.h

# Included from bits/stdint-uintn.h
_BITS_STDINT_UINTN_H = 1

# Included from bits/types.h
_BITS_TYPES_H = 1
__S32_TYPE = int
__SWORD_TYPE = int
__SLONG32_TYPE = int

# Included from bits/typesizes.h
_BITS_TYPESIZES_H = 1
__FSWORD_T_TYPE = __SWORD_TYPE
__PID_T_TYPE = __S32_TYPE
__DADDR_T_TYPE = __S32_TYPE
__KEY_T_TYPE = __S32_TYPE
__CLOCKID_T_TYPE = __S32_TYPE
__SSIZE_T_TYPE = __SWORD_TYPE
__OFF_T_MATCHES_OFF64_T = 1
__INO_T_MATCHES_INO64_T = 1
__RLIM_T_MATCHES_RLIM64_T = 1
__STATFS_MATCHES_STATFS64 = 1
__KERNEL_OLD_TIMEVAL_MATCHES_TIMEVAL64 = 1
__RLIM_T_MATCHES_RLIM64_T = 0
__STATFS_MATCHES_STATFS64 = 0
__KERNEL_OLD_TIMEVAL_MATCHES_TIMEVAL64 = 0
__FD_SETSIZE = 1024

# Included from bits/time64.h
_BITS_TIME64_H = 1

# Included from sys/socket.h
_SYS_SOCKET_H = 1

# Included from bits/types/struct_iovec.h
__iovec_defined = 1

# Included from bits/socket.h
from TYPES import *

# Included from bits/socket_type.h
PF_UNSPEC = 0
PF_LOCAL = 1
PF_UNIX = PF_LOCAL
PF_FILE = PF_LOCAL
PF_INET = 2
PF_AX25 = 3
PF_IPX = 4
PF_APPLETALK = 5
PF_NETROM = 6
PF_BRIDGE = 7
PF_ATMPVC = 8
PF_X25 = 9
PF_INET6 = 10
PF_ROSE = 11
PF_DECnet = 12
PF_NETBEUI = 13
PF_SECURITY = 14
PF_KEY = 15
PF_NETLINK = 16
PF_ROUTE = PF_NETLINK
PF_PACKET = 17
PF_ASH = 18
PF_ECONET = 19
PF_ATMSVC = 20
PF_RDS = 21
PF_SNA = 22
PF_IRDA = 23
PF_PPPOX = 24
PF_WANPIPE = 25
PF_LLC = 26
PF_IB = 27
PF_MPLS = 28
PF_CAN = 29
PF_TIPC = 30
PF_BLUETOOTH = 31
PF_IUCV = 32
PF_RXRPC = 33
PF_ISDN = 34
PF_PHONET = 35
PF_IEEE802154 = 36
PF_CAIF = 37
PF_ALG = 38
PF_NFC = 39
PF_VSOCK = 40
PF_KCM = 41
PF_QIPCRTR = 42
PF_SMC = 43
PF_XDP = 44
PF_MCTP = 45
PF_MAX = 46
AF_UNSPEC = PF_UNSPEC
AF_LOCAL = PF_LOCAL
AF_UNIX = PF_UNIX
AF_FILE = PF_FILE
AF_INET = PF_INET
AF_AX25 = PF_AX25
AF_IPX = PF_IPX
AF_APPLETALK = PF_APPLETALK
AF_NETROM = PF_NETROM
AF_BRIDGE = PF_BRIDGE
AF_ATMPVC = PF_ATMPVC
AF_X25 = PF_X25
AF_INET6 = PF_INET6
AF_ROSE = PF_ROSE
AF_DECnet = PF_DECnet
AF_NETBEUI = PF_NETBEUI
AF_SECURITY = PF_SECURITY
AF_KEY = PF_KEY
AF_NETLINK = PF_NETLINK
AF_ROUTE = PF_ROUTE
AF_PACKET = PF_PACKET
AF_ASH = PF_ASH
AF_ECONET = PF_ECONET
AF_ATMSVC = PF_ATMSVC
AF_RDS = PF_RDS
AF_SNA = PF_SNA
AF_IRDA = PF_IRDA
AF_PPPOX = PF_PPPOX
AF_WANPIPE = PF_WANPIPE
AF_LLC = PF_LLC
AF_IB = PF_IB
AF_MPLS = PF_MPLS
AF_CAN = PF_CAN
AF_TIPC = PF_TIPC
AF_BLUETOOTH = PF_BLUETOOTH
AF_IUCV = PF_IUCV
AF_RXRPC = PF_RXRPC
AF_ISDN = PF_ISDN
AF_PHONET = PF_PHONET
AF_IEEE802154 = PF_IEEE802154
AF_CAIF = PF_CAIF
AF_ALG = PF_ALG
AF_NFC = PF_NFC
AF_VSOCK = PF_VSOCK
AF_KCM = PF_KCM
AF_QIPCRTR = PF_QIPCRTR
AF_SMC = PF_SMC
AF_XDP = PF_XDP
AF_MCTP = PF_MCTP
AF_MAX = PF_MAX
SOL_RAW = 255
SOL_DECNET = 261
SOL_X25 = 262
SOL_PACKET = 263
SOL_ATM = 264
SOL_AAL = 265
SOL_IRDA = 266
SOL_NETBEUI = 267
SOL_LLC = 268
SOL_DCCP = 269
SOL_NETLINK = 270
SOL_TIPC = 271
SOL_RXRPC = 272
SOL_PPPOL2TP = 273
SOL_BLUETOOTH = 274
SOL_PNPIPE = 275
SOL_RDS = 276
SOL_IUCV = 277
SOL_CAIF = 278
SOL_ALG = 279
SOL_NFC = 280
SOL_KCM = 281
SOL_TLS = 282
SOL_XDP = 283
SOL_MPTCP = 284
SOL_MCTP = 285
SOL_SMC = 286
SOL_VSOCK = 287
SOMAXCONN = 4096

# Included from bits/sockaddr.h
_BITS_SOCKADDR_H = 1
def __SOCKADDR_COMMON(sa_prefix): return \

_SS_SIZE = 128
def CMSG_FIRSTHDR(mhdr): return \


# Included from bits/types/time_t.h
__time_t_defined = 1

# Included from asm/socket.h

# Included from asm-generic/socket.h

# Included from linux/posix_types.h

# Included from linux/stddef.h
def __struct_group_tag(TAG): return TAG

__FD_SETSIZE = 1024

# Included from asm/posix_types.h

# Included from asm/posix_types_32.h

# Included from asm-generic/posix_types.h

# Included from asm/bitsperlong.h
__BITS_PER_LONG = 64
__BITS_PER_LONG = 32

# Included from asm-generic/bitsperlong.h
__BITS_PER_LONG = 32
__BITS_PER_LONG_LONG = 64

# Included from asm/posix_types_x32.h

# Included from asm/posix_types_64.h

# Included from asm/sockios.h

# Included from asm-generic/sockios.h
FIOSETOWN = 0x8901
SIOCSPGRP = 0x8902
FIOGETOWN = 0x8903
SIOCGPGRP = 0x8904
SIOCATMARK = 0x8905
SIOCGSTAMP_OLD = 0x8906
SIOCGSTAMPNS_OLD = 0x8907
SOL_SOCKET = 1
SO_DEBUG = 1
SO_REUSEADDR = 2
SO_TYPE = 3
SO_ERROR = 4
SO_DONTROUTE = 5
SO_BROADCAST = 6
SO_SNDBUF = 7
SO_RCVBUF = 8
SO_SNDBUFFORCE = 32
SO_RCVBUFFORCE = 33
SO_KEEPALIVE = 9
SO_OOBINLINE = 10
SO_NO_CHECK = 11
SO_PRIORITY = 12
SO_LINGER = 13
SO_BSDCOMPAT = 14
SO_REUSEPORT = 15
SO_PASSCRED = 16
SO_PEERCRED = 17
SO_RCVLOWAT = 18
SO_SNDLOWAT = 19
SO_RCVTIMEO_OLD = 20
SO_SNDTIMEO_OLD = 21
SO_SECURITY_AUTHENTICATION = 22
SO_SECURITY_ENCRYPTION_TRANSPORT = 23
SO_SECURITY_ENCRYPTION_NETWORK = 24
SO_BINDTODEVICE = 25
SO_ATTACH_FILTER = 26
SO_DETACH_FILTER = 27
SO_GET_FILTER = SO_ATTACH_FILTER
SO_PEERNAME = 28
SO_ACCEPTCONN = 30
SO_PEERSEC = 31
SO_PASSSEC = 34
SO_MARK = 36
SO_PROTOCOL = 38
SO_DOMAIN = 39
SO_RXQ_OVFL = 40
SO_WIFI_STATUS = 41
SCM_WIFI_STATUS = SO_WIFI_STATUS
SO_PEEK_OFF = 42
SO_NOFCS = 43
SO_LOCK_FILTER = 44
SO_SELECT_ERR_QUEUE = 45
SO_BUSY_POLL = 46
SO_MAX_PACING_RATE = 47
SO_BPF_EXTENSIONS = 48
SO_INCOMING_CPU = 49
SO_ATTACH_BPF = 50
SO_DETACH_BPF = SO_DETACH_FILTER
SO_ATTACH_REUSEPORT_CBPF = 51
SO_ATTACH_REUSEPORT_EBPF = 52
SO_CNX_ADVICE = 53
SCM_TIMESTAMPING_OPT_STATS = 54
SO_MEMINFO = 55
SO_INCOMING_NAPI_ID = 56
SO_COOKIE = 57
SCM_TIMESTAMPING_PKTINFO = 58
SO_PEERGROUPS = 59
SO_ZEROCOPY = 60
SO_TXTIME = 61
SCM_TXTIME = SO_TXTIME
SO_BINDTOIFINDEX = 62
SO_TIMESTAMP_OLD = 29
SO_TIMESTAMPNS_OLD = 35
SO_TIMESTAMPING_OLD = 37
SO_TIMESTAMP_NEW = 63
SO_TIMESTAMPNS_NEW = 64
SO_TIMESTAMPING_NEW = 65
SO_RCVTIMEO_NEW = 66
SO_SNDTIMEO_NEW = 67
SO_DETACH_REUSEPORT_BPF = 68
SO_PREFER_BUSY_POLL = 69
SO_BUSY_POLL_BUDGET = 70
SO_NETNS_COOKIE = 71
SO_BUF_LOCK = 72
SO_RESERVE_MEM = 73
SO_TXREHASH = 74
SO_RCVMARK = 75
SO_PASSPIDFD = 76
SO_PEERPIDFD = 77
SO_DEVMEM_LINEAR = 78
SCM_DEVMEM_LINEAR = SO_DEVMEM_LINEAR
SO_DEVMEM_DMABUF = 79
SCM_DEVMEM_DMABUF = SO_DEVMEM_DMABUF
SO_DEVMEM_DONTNEED = 80
SCM_TS_OPT_ID = 81
SO_RCVPRIORITY = 82
SO_PASSRIGHTS = 83
SO_INQ = 84
SCM_INQ = SO_INQ
SO_TIMESTAMP = SO_TIMESTAMP_OLD
SO_TIMESTAMPNS = SO_TIMESTAMPNS_OLD
SO_TIMESTAMPING = SO_TIMESTAMPING_OLD
SO_RCVTIMEO = SO_RCVTIMEO_OLD
SO_SNDTIMEO = SO_SNDTIMEO_OLD
SCM_TIMESTAMP = SO_TIMESTAMP
SCM_TIMESTAMPNS = SO_TIMESTAMPNS
SCM_TIMESTAMPING = SO_TIMESTAMPING
SO_DEBUG = 1

# Included from bits/socket-constants.h
SOL_SOCKET = 1
SO_ACCEPTCONN = 30
SO_BROADCAST = 6
SO_DONTROUTE = 5
SO_ERROR = 4
SO_KEEPALIVE = 9
SO_LINGER = 13
SO_OOBINLINE = 10
SO_RCVBUF = 8
SO_RCVLOWAT = 18
SO_REUSEADDR = 2
SO_SNDBUF = 7
SO_SNDLOWAT = 19
SO_TYPE = 3
SO_RCVTIMEO = 66
SO_SNDTIMEO = 67
SO_TIMESTAMP = 63
SO_TIMESTAMPNS = 64
SO_TIMESTAMPING = 65
SO_RCVTIMEO = 20
SO_SNDTIMEO = 21
SO_TIMESTAMP = 29
SO_TIMESTAMPNS = 35
SO_TIMESTAMPING = 37
SO_RCVTIMEO_OLD = 20
SO_SNDTIMEO_OLD = 21
SO_RCVTIMEO_NEW = 66
SO_SNDTIMEO_NEW = 67
SO_TIMESTAMP_OLD = 29
SO_TIMESTAMPNS_OLD = 35
SO_TIMESTAMPING_OLD = 37
SO_TIMESTAMP_NEW = 63
SO_TIMESTAMPNS_NEW = 64
SO_TIMESTAMPING_NEW = 65
SO_RCVTIMEO = SO_RCVTIMEO_NEW
SO_SNDTIMEO = SO_SNDTIMEO_NEW
SO_TIMESTAMP = SO_TIMESTAMP_NEW
SO_TIMESTAMPNS = SO_TIMESTAMPNS_NEW
SO_TIMESTAMPING = SO_TIMESTAMPING_NEW
SO_RCVTIMEO = SO_RCVTIMEO_OLD
SO_SNDTIMEO = SO_SNDTIMEO_OLD
SO_TIMESTAMP = SO_TIMESTAMP_OLD
SO_TIMESTAMPNS = SO_TIMESTAMPNS_OLD
SO_TIMESTAMPING = SO_TIMESTAMPING_OLD

# Included from bits/types/struct_osockaddr.h
__osockaddr_defined = 1

# Included from bits/socket2.h

# Included from bits/in.h
__USE_KERNEL_IPV6_DEFS = 1
__USE_KERNEL_IPV6_DEFS = 0
IP_OPTIONS = 4
IP_HDRINCL = 3
IP_TOS = 1
IP_TTL = 2
IP_RECVOPTS = 6
IP_RETOPTS = 7
IP_MULTICAST_IF = 32
IP_MULTICAST_TTL = 33
IP_MULTICAST_LOOP = 34
IP_ADD_MEMBERSHIP = 35
IP_DROP_MEMBERSHIP = 36
IP_UNBLOCK_SOURCE = 37
IP_BLOCK_SOURCE = 38
IP_ADD_SOURCE_MEMBERSHIP = 39
IP_DROP_SOURCE_MEMBERSHIP = 40
IP_MSFILTER = 41
MCAST_JOIN_GROUP = 42
MCAST_BLOCK_SOURCE = 43
MCAST_UNBLOCK_SOURCE = 44
MCAST_LEAVE_GROUP = 45
MCAST_JOIN_SOURCE_GROUP = 46
MCAST_LEAVE_SOURCE_GROUP = 47
MCAST_MSFILTER = 48
IP_MULTICAST_ALL = 49
IP_UNICAST_IF = 50
MCAST_EXCLUDE = 0
MCAST_INCLUDE = 1
IP_ROUTER_ALERT = 5
IP_PKTINFO = 8
IP_PKTOPTIONS = 9
IP_PMTUDISC = 10
IP_MTU_DISCOVER = 10
IP_RECVERR = 11
IP_RECVTTL = 12
IP_RECVTOS = 13
IP_MTU = 14
IP_FREEBIND = 15
IP_IPSEC_POLICY = 16
IP_XFRM_POLICY = 17
IP_PASSSEC = 18
IP_TRANSPARENT = 19
IP_MULTICAST_ALL = 49
IP_ORIGDSTADDR = 20
IP_RECVORIGDSTADDR = IP_ORIGDSTADDR
IP_MINTTL = 21
IP_NODEFRAG = 22
IP_CHECKSUM = 23
IP_BIND_ADDRESS_NO_PORT = 24
IP_RECVFRAGSIZE = 25
IP_RECVERR_RFC4884 = 26
IP_PMTUDISC_DONT = 0
IP_PMTUDISC_WANT = 1
IP_PMTUDISC_DO = 2
IP_PMTUDISC_PROBE = 3
IP_PMTUDISC_INTERFACE = 4
IP_PMTUDISC_OMIT = 5
IP_MULTICAST_IF = 32
IP_MULTICAST_TTL = 33
IP_MULTICAST_LOOP = 34
IP_ADD_MEMBERSHIP = 35
IP_DROP_MEMBERSHIP = 36
IP_UNBLOCK_SOURCE = 37
IP_BLOCK_SOURCE = 38
IP_ADD_SOURCE_MEMBERSHIP = 39
IP_DROP_SOURCE_MEMBERSHIP = 40
IP_MSFILTER = 41
IP_MULTICAST_ALL = 49
IP_UNICAST_IF = 50
IP_LOCAL_PORT_RANGE = 51
IP_PROTOCOL = 52
SOL_IP = 0
IP_DEFAULT_MULTICAST_TTL = 1
IP_DEFAULT_MULTICAST_LOOP = 1
IP_MAX_MEMBERSHIPS = 20
IPV6_ADDRFORM = 1
IPV6_2292PKTINFO = 2
IPV6_2292HOPOPTS = 3
IPV6_2292DSTOPTS = 4
IPV6_2292RTHDR = 5
IPV6_2292PKTOPTIONS = 6
IPV6_CHECKSUM = 7
IPV6_2292HOPLIMIT = 8
IPV6_NEXTHOP = 9
IPV6_AUTHHDR = 10
IPV6_UNICAST_HOPS = 16
IPV6_MULTICAST_IF = 17
IPV6_MULTICAST_HOPS = 18
IPV6_MULTICAST_LOOP = 19
IPV6_JOIN_GROUP = 20
IPV6_LEAVE_GROUP = 21
IPV6_ROUTER_ALERT = 22
IPV6_MTU_DISCOVER = 23
IPV6_MTU = 24
IPV6_RECVERR = 25
IPV6_V6ONLY = 26
IPV6_JOIN_ANYCAST = 27
IPV6_LEAVE_ANYCAST = 28
IPV6_MULTICAST_ALL = 29
IPV6_ROUTER_ALERT_ISOLATE = 30
IPV6_RECVERR_RFC4884 = 31
IPV6_IPSEC_POLICY = 34
IPV6_XFRM_POLICY = 35
IPV6_HDRINCL = 36
IPV6_RECVPKTINFO = 49
IPV6_PKTINFO = 50
IPV6_RECVHOPLIMIT = 51
IPV6_HOPLIMIT = 52
IPV6_RECVHOPOPTS = 53
IPV6_HOPOPTS = 54
IPV6_RTHDRDSTOPTS = 55
IPV6_RECVRTHDR = 56
IPV6_RTHDR = 57
IPV6_RECVDSTOPTS = 58
IPV6_DSTOPTS = 59
IPV6_RECVPATHMTU = 60
IPV6_PATHMTU = 61
IPV6_DONTFRAG = 62
IPV6_RECVTCLASS = 66
IPV6_TCLASS = 67
IPV6_AUTOFLOWLABEL = 70
IPV6_ADDR_PREFERENCES = 72
IPV6_MINHOPCOUNT = 73
IPV6_ORIGDSTADDR = 74
IPV6_RECVORIGDSTADDR = IPV6_ORIGDSTADDR
IPV6_TRANSPARENT = 75
IPV6_UNICAST_IF = 76
IPV6_RECVFRAGSIZE = 77
IPV6_FREEBIND = 78
IPV6_ADD_MEMBERSHIP = IPV6_JOIN_GROUP
IPV6_DROP_MEMBERSHIP = IPV6_LEAVE_GROUP
IPV6_RXHOPOPTS = IPV6_HOPOPTS
IPV6_RXDSTOPTS = IPV6_DSTOPTS
IPV6_PMTUDISC_DONT = 0
IPV6_PMTUDISC_WANT = 1
IPV6_PMTUDISC_DO = 2
IPV6_PMTUDISC_PROBE = 3
IPV6_PMTUDISC_INTERFACE = 4
IPV6_PMTUDISC_OMIT = 5
SOL_IPV6 = 41
SOL_ICMPV6 = 58
IPV6_RTHDR_LOOSE = 0
IPV6_RTHDR_STRICT = 1
IPV6_RTHDR_TYPE_0 = 0
def IN_CLASSA(a): return ((((in_addr_t)(a)) & 0x80000000) == 0)

IN_CLASSA_NET = 0xff000000
IN_CLASSA_NSHIFT = 24
IN_CLASSA_HOST = (0xffffffff & ~IN_CLASSA_NET)
IN_CLASSA_MAX = 128
def IN_CLASSB(a): return ((((in_addr_t)(a)) & 0xc0000000) == 0x80000000)

IN_CLASSB_NET = 0xffff0000
IN_CLASSB_NSHIFT = 16
IN_CLASSB_HOST = (0xffffffff & ~IN_CLASSB_NET)
IN_CLASSB_MAX = 65536
def IN_CLASSC(a): return ((((in_addr_t)(a)) & 0xe0000000) == 0xc0000000)

IN_CLASSC_NET = 0xffffff00
IN_CLASSC_NSHIFT = 8
IN_CLASSC_HOST = (0xffffffff & ~IN_CLASSC_NET)
def IN_CLASSD(a): return ((((in_addr_t)(a)) & 0xf0000000) == 0xe0000000)

def IN_MULTICAST(a): return IN_CLASSD(a)

def IN_EXPERIMENTAL(a): return ((((in_addr_t)(a)) & 0xe0000000) == 0xe0000000)

def IN_BADCLASS(a): return ((((in_addr_t)(a)) & 0xf0000000) == 0xf0000000)

IN_LOOPBACKNET = 127
INET_ADDRSTRLEN = 16
INET6_ADDRSTRLEN = 46

# Included from endian.h
_ENDIAN_H = 1

# Included from bits/endian.h
_BITS_ENDIAN_H = 1
__LITTLE_ENDIAN = 1234
__BIG_ENDIAN = 4321
__PDP_ENDIAN = 3412

# Included from bits/endianness.h
_BITS_ENDIANNESS_H = 1
__BYTE_ORDER = __LITTLE_ENDIAN
__FLOAT_WORD_ORDER = __BYTE_ORDER
LITTLE_ENDIAN = __LITTLE_ENDIAN
BIG_ENDIAN = __BIG_ENDIAN
PDP_ENDIAN = __PDP_ENDIAN
BYTE_ORDER = __BYTE_ORDER

# Included from bits/byteswap.h
_BITS_BYTESWAP_H = 1
def __bswap_constant_16(x): return \

def __bswap_constant_32(x): return \

def __bswap_constant_64(x): return \


# Included from bits/uintn-identity.h
_BITS_UINTN_IDENTITY_H = 1
def htobe16(x): return __bswap_16 (x)

def htole16(x): return __uint16_identity (x)

def be16toh(x): return __bswap_16 (x)

def le16toh(x): return __uint16_identity (x)

def htobe32(x): return __bswap_32 (x)

def htole32(x): return __uint32_identity (x)

def be32toh(x): return __bswap_32 (x)

def le32toh(x): return __uint32_identity (x)

def htobe64(x): return __bswap_64 (x)

def htole64(x): return __uint64_identity (x)

def be64toh(x): return __bswap_64 (x)

def le64toh(x): return __uint64_identity (x)

def htobe16(x): return __uint16_identity (x)

def htole16(x): return __bswap_16 (x)

def be16toh(x): return __uint16_identity (x)

def le16toh(x): return __bswap_16 (x)

def htobe32(x): return __uint32_identity (x)

def htole32(x): return __bswap_32 (x)

def be32toh(x): return __uint32_identity (x)

def le32toh(x): return __bswap_32 (x)

def htobe64(x): return __uint64_identity (x)

def htole64(x): return __bswap_64 (x)

def be64toh(x): return __uint64_identity (x)

def le64toh(x): return __bswap_64 (x)

def ntohl(x): return __uint32_identity (x)

def ntohs(x): return __uint16_identity (x)

def htonl(x): return __uint32_identity (x)

def htons(x): return __uint16_identity (x)

def ntohl(x): return __bswap_32 (x)

def ntohs(x): return __bswap_16 (x)

def htonl(x): return __bswap_32 (x)

def htons(x): return __bswap_16 (x)

def IN6_IS_ADDR_UNSPECIFIED(a): return \

def IN6_IS_ADDR_LOOPBACK(a): return \

def IN6_IS_ADDR_LINKLOCAL(a): return \

def IN6_IS_ADDR_SITELOCAL(a): return \

def IN6_IS_ADDR_V4MAPPED(a): return \

def IN6_IS_ADDR_V4COMPAT(a): return \

def IN6_IS_ADDR_UNSPECIFIED(a): return \

def IN6_IS_ADDR_LOOPBACK(a): return \

def IN6_IS_ADDR_LINKLOCAL(a): return \

def IN6_IS_ADDR_SITELOCAL(a): return \

def IN6_IS_ADDR_V4MAPPED(a): return \

def IN6_IS_ADDR_V4COMPAT(a): return \

def IN6_IS_ADDR_MC_NODELOCAL(a): return \

def IN6_IS_ADDR_MC_LINKLOCAL(a): return \

def IN6_IS_ADDR_MC_SITELOCAL(a): return \

def IN6_IS_ADDR_MC_ORGLOCAL(a): return \

def IN6_IS_ADDR_MC_GLOBAL(a): return \

