# Generated by h2py from /usr/include/sys/types.h
_SYS_TYPES_H = 1

# Included from features.h
_FEATURES_H = 1
def __GLIBC_USE(F): return __GLIBC_USE_ ## F

_DEFAULT_SOURCE = 1
_ISOC23_SOURCE = 1
_ISOC95_SOURCE = 1
_ISOC99_SOURCE = 1
_ISOC11_SOURCE = 1
_ISOC23_SOURCE = 1
_ISOC2Y_SOURCE = 1
_POSIX_SOURCE = 1
_POSIX_C_SOURCE = 202405L
_XOPEN_SOURCE = 800
_XOPEN_SOURCE_EXTENDED = 1
_LARGEFILE64_SOURCE = 1
_DEFAULT_SOURCE = 1
_ATFILE_SOURCE = 1
_DYNAMIC_STACK_SIZE_SOURCE = 1
_DEFAULT_SOURCE = 1
__GLIBC_USE_ISOC2Y = 1
__GLIBC_USE_ISOC2Y = 0
__GLIBC_USE_ISOC23 = 1
__GLIBC_USE_ISOC23 = 0
__USE_ISOC11 = 1
__USE_ISOC99 = 1
__USE_ISOC95 = 1
__USE_ISOC11 = 1
__USE_ISOCXX11 = 1
__USE_ISOC99 = 1
__USE_POSIX_IMPLICITLY = 1
_POSIX_SOURCE = 1
_POSIX_C_SOURCE = 202405L
_POSIX_SOURCE = 1
_POSIX_C_SOURCE = 2
_POSIX_C_SOURCE = 199506L
_POSIX_C_SOURCE = 200112L
_POSIX_C_SOURCE = 200809L
_POSIX_C_SOURCE = 202405L
__USE_POSIX_IMPLICITLY = 1
_POSIX_SOURCE = 1
_POSIX_C_SOURCE = 199506L
__USE_POSIX = 1
__USE_POSIX2 = 1
__USE_POSIX199309 = 1
__USE_POSIX199506 = 1
__USE_XOPEN2K = 1
__USE_ISOC95 = 1
__USE_ISOC99 = 1
__USE_XOPEN2K8 = 1
_ATFILE_SOURCE = 1
__USE_XOPEN2K24 = 1
__USE_XOPEN = 1
__USE_XOPEN_EXTENDED = 1
__USE_UNIX98 = 1
_LARGEFILE_SOURCE = 1
__USE_XOPEN2K8 = 1
__USE_XOPEN2K8XSI = 1
__USE_XOPEN2K24 = 1
__USE_XOPEN2K24XSI = 1
__USE_XOPEN2K = 1
__USE_XOPEN2KXSI = 1
__USE_ISOC95 = 1
__USE_ISOC99 = 1
__USE_XOPEN_EXTENDED = 1
__USE_LARGEFILE = 1
__USE_LARGEFILE64 = 1
__USE_FILE_OFFSET64 = 1

# Included from features-time64.h

# Included from bits/wordsize.h
__WORDSIZE = 64
__WORDSIZE = 32
__WORDSIZE32_SIZE_ULONG = 0
__WORDSIZE32_PTRDIFF_LONG = 0
__WORDSIZE_TIME64_COMPAT32 = 1
__SYSCALL_WORDSIZE = 64

# Included from bits/timesize.h
__TIMESIZE = 64
__TIMESIZE = __WORDSIZE
__USE_TIME_BITS64 = 1
__USE_TIME_BITS64 = 1
__USE_TIME64_REDIRECTS = 1
__USE_MISC = 1
__USE_ATFILE = 1
__USE_DYNAMIC_STACK_SIZE = 1
__USE_GNU = 1
__USE_FORTIFY_LEVEL = 3
__USE_FORTIFY_LEVEL = 2
__USE_FORTIFY_LEVEL = 1
__USE_FORTIFY_LEVEL = 0
__GLIBC_USE_DEPRECATED_GETS = 0
__GLIBC_USE_DEPRECATED_GETS = 1
__GLIBC_USE_DEPRECATED_SCANF = 1
__GLIBC_USE_DEPRECATED_SCANF = 0
__GLIBC_USE_C23_STRTOL = 1
__GLIBC_USE_C23_STRTOL = 0

# Included from stdc-predef.h
_STDC_PREDEF_H = 1
__STDC_IEC_559__ = 1
__STDC_IEC_60559_BFP__ = 201404L
__STDC_IEC_559__ = 1
__STDC_IEC_60559_BFP__ = 201404L
__STDC_IEC_559_COMPLEX__ = 1
__STDC_IEC_60559_COMPLEX__ = 201404L
__STDC_IEC_559_COMPLEX__ = 1
__STDC_IEC_60559_COMPLEX__ = 201404L
__STDC_ISO_10646__ = 201706L
__GNU_LIBRARY__ = 6
__GLIBC__ = 2
__GLIBC_MINOR__ = 43

# Included from sys/cdefs.h
_SYS_CDEFS_H = 1
def __glibc_has_attribute(attr): return __has_attribute (attr)

def __glibc_has_attribute(attr): return 0

def __glibc_has_builtin(name): return __has_builtin (name)

def __glibc_has_builtin(name): return 0

def __glibc_has_extension(ext): return __has_extension (ext)

def __glibc_has_extension(ext): return 0

def __NTH(fct): return fct

def __NTHNL(fct): return fct

def __NTH(fct): return fct

def __P(args): return args

def __PMT(args): return args

def __STRING(x): return #x

def __bos(ptr): return __builtin_object_size (ptr, __USE_FORTIFY_LEVEL > 1)

def __bos0(ptr): return __builtin_object_size (ptr, 0)

def __glibc_objsize0(__o): return __builtin_dynamic_object_size (__o, 0)

def __glibc_objsize(__o): return __builtin_dynamic_object_size (__o, 1)

def __glibc_objsize0(__o): return __bos0 (__o)

def __glibc_objsize(__o): return __bos (__o)

def __glibc_unsigned_or_positive(__l): return \

__fortify_use_clang = 1
def __fortify_clang_pass_object_size_n(n): return \

__fortify_clang_pass_object_size0 = \
  __fortify_clang_pass_object_size_n (0)
__fortify_clang_pass_object_size = \
  __fortify_clang_pass_object_size_n (__USE_FORTIFY_LEVEL > 1)
def __fortify_clang_pass_dynamic_object_size_n(n): return \

__fortify_clang_pass_dynamic_object_size0 = \
  __fortify_clang_pass_dynamic_object_size_n (0)
__fortify_clang_pass_dynamic_object_size = \
  __fortify_clang_pass_dynamic_object_size_n (1)
def __fortify_clang_unavailable(__msg): return \

__fortify_use_clang = 0
def __warnattr(msg): return __attribute__((__warning__ (msg)))

__flexarr = []
__glibc_c99_flexarr_available = 1
__flexarr = []
__glibc_c99_flexarr_available = 1
__flexarr = [0]
__glibc_c99_flexarr_available = 1
__flexarr = [1]
__glibc_c99_flexarr_available = 0
def __ASMNAME(cname): return __ASMNAME2 (__USER_LABEL_PREFIX__, cname)

def __attribute__(xyz): return  

def __attribute_alloc_size__(params): return \

def __attribute_alloc_size__(params): return  

def __attribute_alloc_align__(param): return \

def __attribute_alloc_align__(param): return  

def __attribute_deprecated_msg__(msg): return \

def __attribute_deprecated_msg__(msg): return __attribute_deprecated__

def __attribute_format_arg__(x): return __attribute__ ((__format_arg__ (x)))

def __attribute_format_arg__(x): return  

def __nonnull(params): return __attribute_nonnull__ (params)

def __glibc_unlikely(cond): return __builtin_expect ((cond), 0)

def __glibc_likely(cond): return __builtin_expect ((cond), 1)

def __glibc_unlikely(cond): return (cond)

def __glibc_likely(cond): return (cond)

def __attribute_copy__(arg): return __attribute__ ((__copy__ (arg)))


# Included from bits/long-double.h
__LDOUBLE_REDIRECTS_TO_FLOAT128_ABI = 0
def __LDBL_REDIR_DECL(name): return \

def __LDBL_REDIR2_DECL(name): return \

__LDBL_COMPAT = 1
def __LDBL_REDIR2_DECL(name): return \

def __LDBL_REDIR_DECL(name): return \

def __glibc_macro_warning(message): return \

__HAVE_GENERIC_SELECTION = 1
__HAVE_GENERIC_SELECTION = 0
def __attr_access_none(argno): return __attribute__ ((__access__ (__none__, argno)))

__USE_LARGEFILE = 1
__USE_LARGEFILE64 = 1
__USE_EXTERN_INLINES = 1

# Included from gnu/stubs.h

# Included from gnu/stubs-32.h

# Included from gnu/stubs-64.h

# Included from bits/types.h
_BITS_TYPES_H = 1
__S32_TYPE = int
__SWORD_TYPE = int
__SLONG32_TYPE = int

# Included from bits/typesizes.h
_BITS_TYPESIZES_H = 1
__FSWORD_T_TYPE = __SWORD_TYPE
__PID_T_TYPE = __S32_TYPE
__DADDR_T_TYPE = __S32_TYPE
__KEY_T_TYPE = __S32_TYPE
__CLOCKID_T_TYPE = __S32_TYPE
__SSIZE_T_TYPE = __SWORD_TYPE
__OFF_T_MATCHES_OFF64_T = 1
__INO_T_MATCHES_INO64_T = 1
__RLIM_T_MATCHES_RLIM64_T = 1
__STATFS_MATCHES_STATFS64 = 1
__KERNEL_OLD_TIMEVAL_MATCHES_TIMEVAL64 = 1
__RLIM_T_MATCHES_RLIM64_T = 0
__STATFS_MATCHES_STATFS64 = 0
__KERNEL_OLD_TIMEVAL_MATCHES_TIMEVAL64 = 0
__FD_SETSIZE = 1024

# Included from bits/time64.h
_BITS_TIME64_H = 1

# Included from bits/types/clock_t.h
__clock_t_defined = 1

# Included from bits/types/clockid_t.h
__clockid_t_defined = 1

# Included from bits/types/time_t.h
__time_t_defined = 1

# Included from bits/types/timer_t.h
__timer_t_defined = 1

# Included from bits/stdint-intn.h
_BITS_STDINT_INTN_H = 1
__BIT_TYPES_DEFINED__ = 1

# Included from endian.h
_ENDIAN_H = 1

# Included from bits/endian.h
_BITS_ENDIAN_H = 1
__LITTLE_ENDIAN = 1234
__BIG_ENDIAN = 4321
__PDP_ENDIAN = 3412

# Included from bits/endianness.h
_BITS_ENDIANNESS_H = 1
__BYTE_ORDER = __LITTLE_ENDIAN
__FLOAT_WORD_ORDER = __BYTE_ORDER
LITTLE_ENDIAN = __LITTLE_ENDIAN
BIG_ENDIAN = __BIG_ENDIAN
PDP_ENDIAN = __PDP_ENDIAN
BYTE_ORDER = __BYTE_ORDER

# Included from bits/byteswap.h
_BITS_BYTESWAP_H = 1
def __bswap_constant_16(x): return \

def __bswap_constant_32(x): return \

def __bswap_constant_64(x): return \


# Included from bits/uintn-identity.h
_BITS_UINTN_IDENTITY_H = 1
def htobe16(x): return __bswap_16 (x)

def htole16(x): return __uint16_identity (x)

def be16toh(x): return __bswap_16 (x)

def le16toh(x): return __uint16_identity (x)

def htobe32(x): return __bswap_32 (x)

def htole32(x): return __uint32_identity (x)

def be32toh(x): return __bswap_32 (x)

def le32toh(x): return __uint32_identity (x)

def htobe64(x): return __bswap_64 (x)

def htole64(x): return __uint64_identity (x)

def be64toh(x): return __bswap_64 (x)

def le64toh(x): return __uint64_identity (x)

def htobe16(x): return __uint16_identity (x)

def htole16(x): return __bswap_16 (x)

def be16toh(x): return __uint16_identity (x)

def le16toh(x): return __bswap_16 (x)

def htobe32(x): return __uint32_identity (x)

def htole32(x): return __bswap_32 (x)

def be32toh(x): return __uint32_identity (x)

def le32toh(x): return __bswap_32 (x)

def htobe64(x): return __uint64_identity (x)

def htole64(x): return __bswap_64 (x)

def be64toh(x): return __uint64_identity (x)

def le64toh(x): return __bswap_64 (x)


# Included from sys/select.h
_SYS_SELECT_H = 1

# Included from bits/select.h
def __FD_ZERO(s): return \


# Included from bits/types/sigset_t.h
__sigset_t_defined = 1

# Included from bits/types/__sigset_t.h

# Included from bits/types/struct_timeval.h
__timeval_defined = 1

# Included from bits/types/struct_timespec.h
_STRUCT_TIMESPEC = 1
def __FD_ELT(d): return ((d) / __NFDBITS)

FD_SETSIZE = __FD_SETSIZE
def FD_ZERO(fdsetp): return __FD_ZERO (fdsetp)


# Included from bits/select2.h

# Included from bits/select-decl.h
_BITS_SELECT_DECL_H = 1
def __FD_ELT(d): return \


# Included from bits/pthreadtypes.h
_BITS_PTHREADTYPES_COMMON_H = 1

# Included from bits/thread-shared-types.h
_THREAD_SHARED_TYPES_H = 1

# Included from bits/pthreadtypes-arch.h
_BITS_PTHREADTYPES_ARCH_H = 1
__SIZEOF_PTHREAD_MUTEX_T = 40
__SIZEOF_PTHREAD_ATTR_T = 56
__SIZEOF_PTHREAD_RWLOCK_T = 56
__SIZEOF_PTHREAD_BARRIER_T = 32
__SIZEOF_PTHREAD_MUTEX_T = 32
__SIZEOF_PTHREAD_ATTR_T = 32
__SIZEOF_PTHREAD_RWLOCK_T = 44
__SIZEOF_PTHREAD_BARRIER_T = 20
__SIZEOF_PTHREAD_MUTEX_T = 24
__SIZEOF_PTHREAD_ATTR_T = 36
__SIZEOF_PTHREAD_RWLOCK_T = 32
__SIZEOF_PTHREAD_BARRIER_T = 20
__SIZEOF_PTHREAD_MUTEXATTR_T = 4
__SIZEOF_PTHREAD_COND_T = 48
__SIZEOF_PTHREAD_CONDATTR_T = 4
__SIZEOF_PTHREAD_RWLOCKATTR_T = 8
__SIZEOF_PTHREAD_BARRIERATTR_T = 4

# Included from bits/atomic_wide_counter.h

# Included from bits/struct_mutex.h
_THREAD_MUTEX_INTERNAL_H = 1
__PTHREAD_MUTEX_HAVE_PREV = 1
__PTHREAD_MUTEX_HAVE_PREV = 0
def __PTHREAD_MUTEX_INITIALIZER(__kind): return \

def __PTHREAD_MUTEX_INITIALIZER(__kind): return \


# Included from bits/struct_rwlock.h
def __PTHREAD_RWLOCK_INITIALIZER(__flags): return \

def __PTHREAD_RWLOCK_INITIALIZER(__flags): return \

__ONCE_FLAG_INIT = { 0 }
__have_pthread_attr_t = 1
